============
Introduction
============

| This is **{{ cookiecutter.project_name }}**, a *Python Package* desinged to ...

| Goal of this project is to TODO Document
| Additionally, TODO Document

| This documentation aims to help people understand what are the package's features and to demonstrate
| how to leverage them for their use cases.
| It also presents the overall package design.
